# =========================================================================== #
# Gemspec for Project Extracter.
# =========================================================================== #
require 'extracter/version/version.rb'

Gem::Specification.new { |s|

  s.name    = 'extracter'
  s.version = Extracter::Extracter::VERSION
  s.date    = Time.now.strftime('%Y-%m-%d')

  DESCRIPTION = <<-EOF

This fairly small class/library can be used to extract different archive
formats such as .tar.bz2 or .tbz - archives such as .gem and .lzma
will also work.

You can also extract audio, by making use of class ExtractAudio. The
latter is - and should be - optional though.

Usage example:

    require 'extracter'

    Extracter.new('/foo/bla-1.0.tar.bz2')

The second argument that can be passed to the method new()
specifies where we should extract to, example:

    Extracter.new('/foo/bla-1.0.tar.bz2', '/opt')

This would extract to the /opt directory.

You can query whether input is an archive or not via:

  Extracter.is_archive? 'foo.tar.xz'

As of April 2014 we also provide a bin/extract file, so that
you can simply extract something from the commandline.

Since as of November 2018, class Extracter can also "extract"
.iso files. (The .iso will be mounted to a directory that
will be created, actually.)

If you have a specific suggestion to make this gem more useful
for others, please drop me an email at:

    shevegen@gmail.com

Thank you.

EOF

  s.summary     = DESCRIPTION
  s.description = DESCRIPTION

  s.authors     = ['Robert A. Heiler']
  s.email       = 'shevegen@gmail.com'
  s.files       = Dir['**/*']
  s.files      << 'USAGE.md' 
  s.licenses    = 'GPL-2.0'
  s.homepage    = 'http://rubygems.org/gems/extracter'

  # ========================================================================= #
  # Show this when a user installs the DiamondShell.
  # ========================================================================= #
  s.post_install_message = <<-EOF

  class Extracter can be used to extract archives, such as .tar.gz or
  .zip.

  If you need some help, you can invoke bin/extract via:

      extract --help

  In general, the syntax for extract is kept simple. Just pass in the
  archive that has to be extracted as the first argument to 
  extract ( bin/extract) , and class Extracter will try to extract
  it, if it is a registered archive format.

  In ruby code, you may be able to use class Extracter in this manner:

      require 'extracter'
      Extracter[file_path_here]

  or

      require 'extracter'
      Extracter.new(file_path_here)

  Specific example:

      require 'extracter'
      Extracter.new('htop-2.2.0.tar.xz')

  See the --help option.

  EOF

  s.required_ruby_version     = '>= '+RUBY_VERSION
  s.required_rubygems_version = '>= '+Gem::VERSION
  s.rubygems_version          = '>= '+Gem::VERSION

  # ========================================================================= #
  # Specify the dependencies for this gem:
  # ========================================================================= #
  s.add_dependency 'colours'
  s.add_dependency 'opn'
  s.add_dependency 'remove_file_suffix'

}